@@ -34,34 +34,26 @@
 #include <QSizePolicy>
 #include <QKeySequence>
 
-#include "searchwidget.h"
-#include "playlistsearch.h"
 #include "actioncollection.h"
-#include "tageditor.h"
 #include "collectionlist.h"
-#include "playermanager.h"
-#include "nowplaying.h"
-#include "playlistbox.h"
+#include "iconsupport.h"
+#include "juk_debug.h"
 #include "lyricswidget.h"
 #include "mpris2/mpris2.h"
-#include "juk_debug.h"
+#include "nowplaying.h"
+#include "playermanager.h"
+#include "playlistbox.h"
+#include "playlistsearch.h"
+#include "searchwidget.h"
+#include "tageditor.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 // public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistSplitter::PlaylistSplitter(PlayerManager *player, QWidget *parent) :
-    QSplitter(Qt::Horizontal, parent),
-    m_newVisible(0),
-    m_playlistBox(0),
-    m_searchWidget(0),
-    m_playlistStack(0),
-    m_editor(0),
-    m_nowPlaying(0),
-    m_player(player),
-    m_lyricsWidget(0),
-    m_editorSplitter(0)
-
+PlaylistSplitter::PlaylistSplitter(PlayerManager *player, QWidget *parent)
+  : QSplitter(Qt::Horizontal, parent)
+  , m_player(player)
 {
     setObjectName(QLatin1String("playlistSplitter"));
 
@@ -83,20 +75,24 @@ PlaylistSplitter::~PlaylistSplitter()
     // destroy it now.
 
     delete m_editor;
+    m_editor = nullptr;
 
     delete m_lyricsWidget;
+    m_lyricsWidget = nullptr;
 
     // NowPlaying depends on the PlaylistCollection, so kill it now.
     delete m_nowPlaying;
-    m_nowPlaying = 0;
+    m_nowPlaying = nullptr;
 
     delete m_searchWidget; // Take no chances here either.
+    m_searchWidget = nullptr;
 
     // Since we want to ensure that the shutdown process for the PlaylistCollection
     // (a base class for PlaylistBox) has a chance to write the playlists to disk
     // before they are deleted we're explicitly deleting the PlaylistBox here.
 
     delete m_playlistBox;
+    m_playlistBox = nullptr;
 }
 
 PlaylistInterface *PlaylistSplitter::playlist() const
@@ -110,33 +106,40 @@ PlaylistInterface *PlaylistSplitter::playlist() const
 
 void PlaylistSplitter::setFocus()
 {
-    m_searchWidget->setFocus();
+    if(m_searchWidget->isVisible()) {
+        m_searchWidget->setFocus();
+    } else {
+        slotFocusCurrentPlaylist();
+    }
 }
 
 void PlaylistSplitter::slotFocusCurrentPlaylist()
 {
     Playlist *playlist = m_playlistBox->visiblePlaylist();
 
-    if(playlist) {
-        playlist->setFocus();
-        playlist->clearSelection();
-
-        // Select the top visible (and matching) item.
-
-        PlaylistItem *item = static_cast<PlaylistItem *>(playlist->itemAt(QPoint(0, 0)));
-
-        if(!item)
-            return;
-
-        // A little bit of a hack to make QListView repaint things properly.  Switch
-        // to single selection mode, set the selection and then switch back.
-
-        playlist->setSelectionMode(QTreeWidget::SingleSelection);
-
-        playlist->setCurrentItem(item);
-
-        playlist->setSelectionMode(QTreeWidget::ExtendedSelection);
+    if(!playlist) {
+        return;
     }
+
+    playlist->setFocus();
+    playlist->clearSelection();
+
+    // Select the top visible (and matching) item.
+
+    PlaylistItem *item = static_cast<PlaylistItem *>(playlist->itemAt(QPoint(0, 0)));
+
+    if(!item) {
+        return;
+    }
+
+    // A little bit of a hack to make QListView repaint things properly.  Switch
+    // to single selection mode, set the selection and then switch back.
+
+    playlist->setSelectionMode(QTreeWidget::SingleSelection);
+
+    playlist->setCurrentItem(item);
+
+    playlist->setSelectionMode(QTreeWidget::ExtendedSelection);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -150,19 +153,24 @@ Playlist *PlaylistSplitter::visiblePlaylist() const
 
 void PlaylistSplitter::setupActions()
 {
+    using namespace IconSupport;
+
     KActionCollection* coll = ActionCollection::actions();
     KToggleAction *showSearch =
-	 new KToggleAction(QIcon::fromTheme(QStringLiteral("edit-find")), i18n("Show &Search Bar"), this);
+        new KToggleAction("edit-find"_icon, i18n("Show &Search Bar"), this);
     coll->addAction("showSearch", showSearch);
 
-    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("edit-clear")), i18n("Edit Track Search"), this);
+    QAction *act = new QAction("edit-clear"_icon, i18n("Edit Track Search"), this);
     coll->addAction("editTrackSearch", act);
     coll->setDefaultShortcut(act, Qt::Key_F6);
-    connect(act, SIGNAL(triggered(bool)), SLOT(setFocus()));
+    connect(act, &QAction::triggered,
+            this, &PlaylistSplitter::setFocus);
 }
 
 void PlaylistSplitter::setupLayout()
 {
+    using namespace ActionCollection; // add literal
+
     setOpaqueResize(false);
 
     // Disable the GUI until startup is complete (as indicated by PlaylistBox)
@@ -203,11 +211,11 @@ void PlaylistSplitter::setupLayout()
     m_playlistBox = new PlaylistBox(m_player, this, m_playlistStack);
     m_playlistBox->setObjectName(QLatin1String("playlistBox"));
 
-    connect(m_playlistBox->object(), SIGNAL(signalSelectedItemsChanged()),
-            this, SLOT(slotPlaylistSelectionChanged()));
-    connect(m_playlistBox, SIGNAL(signalPlaylistDestroyed(Playlist*)),
-            m_editor, SLOT(slotPlaylistDestroyed(Playlist*)));
-    connect(m_playlistBox, SIGNAL(startupComplete()), SLOT(slotEnable()));
+    const auto &plistActions = m_playlistBox->collectionActions();
+    connect(plistActions,  &PlaylistCollection::ActionHandler::signalSelectedItemsChanged,
+            this,          &PlaylistSplitter::slotPlaylistSelectionChanged);
+    connect(m_playlistBox, &PlaylistBox::signalPlaylistDestroyed,
+            m_editor,      &TagEditor::slotPlaylistDestroyed);
     connect(m_playlistBox, &QTreeWidget::currentItemChanged,
             this,          &PlaylistSplitter::slotCurrentPlaylistChanged);
 
@@ -229,16 +237,13 @@ void PlaylistSplitter::setupLayout()
 
     m_player->setPlaylistInterface(m_playlistBox);
 
-    // Let interested parties know we're ready
-    connect(m_playlistBox, SIGNAL(startupComplete()), SIGNAL(guiReady()));
-
     insertWidget(0, m_playlistBox);
 
     m_nowPlaying = new NowPlaying(top, m_playlistBox);
-    connect(m_player, SIGNAL(signalItemChanged(FileHandle)),
-            m_nowPlaying, SLOT(slotUpdate(FileHandle)));
-    connect(m_player, SIGNAL(signalItemChanged(FileHandle)),
-            m_lyricsWidget, SLOT(playing(FileHandle)));
+    connect(m_player,       &PlayerManager::signalItemChanged,
+            m_nowPlaying,   &NowPlaying::slotUpdate);
+    connect(m_player,       &PlayerManager::signalItemChanged,
+            m_lyricsWidget, &LyricsWidget::playing);
 
     // Create the search widget -- this must be done after the CollectionList is created.
 
@@ -247,18 +252,18 @@ void PlaylistSplitter::setupLayout()
     // auto-shortcuts don't seem to work and aren't needed anyway.
     KAcceleratorManager::setNoAccel(m_searchWidget);
 
-    connect(m_searchWidget, SIGNAL(signalQueryChanged()),
-            this, SLOT(slotShowSearchResults()));
-    connect(m_searchWidget, SIGNAL(signalDownPressed()),
-            this, SLOT(slotFocusCurrentPlaylist()));
-    connect(m_searchWidget, SIGNAL(signalShown(bool)),
-            m_playlistBox->object(), SLOT(slotSetSearchEnabled(bool)));
-    connect(m_searchWidget, SIGNAL(returnPressed()),
-            m_playlistBox->object(), SLOT(slotPlayFirst()));
-    connect(ActionCollection::action<KToggleAction>("showSearch"), SIGNAL(toggled(bool)),
-            m_searchWidget, SLOT(setEnabled(bool)));
-    connect(m_playlistBox, &PlaylistBox::signalMoveFocusAway,
-            m_searchWidget, &SearchWidget::setFocus);
+    connect(m_searchWidget,   &SearchWidget::signalQueryChanged,
+            this,             &PlaylistSplitter::slotShowSearchResults);
+    connect(m_searchWidget,   &SearchWidget::signalDownPressed,
+            this,             &PlaylistSplitter::slotFocusCurrentPlaylist);
+    connect(m_searchWidget,   &SearchWidget::signalShown,
+            m_playlistBox,    [this](bool e) { m_playlistBox->setSearchEnabled(e); });
+    connect(m_searchWidget,   &SearchWidget::returnPressed,
+            m_playlistBox,    [this]() { m_playlistBox->playFirst(); });
+    connect("showSearch"_act, &QAction::toggled,
+            m_searchWidget,   &SearchWidget::setEnabled);
+    connect(m_playlistBox,    &PlaylistBox::signalMoveFocusAway,
+            m_searchWidget,   qOverload<>(&SearchWidget::setFocus));
 
     topLayout->addWidget(m_nowPlaying);
     topLayout->addWidget(m_searchWidget);
@@ -274,6 +279,8 @@ void PlaylistSplitter::setupLayout()
 
 void PlaylistSplitter::readConfig()
 {
+    using namespace ActionCollection; // add literal
+
     KConfigGroup config(KSharedConfig::openConfig(), "Splitter");
 
     QList<int> splitterSizes = config.readEntry("PlaylistSplitterSizes",QList<int>());
@@ -284,7 +291,7 @@ void PlaylistSplitter::readConfig()
     setSizes(splitterSizes);
 
     bool showSearch = config.readEntry("ShowSearch", true);
-    ActionCollection::action<KToggleAction>("showSearch")->setChecked(showSearch);
+    "showSearch"_act->setChecked(showSearch);
     m_searchWidget->setHidden(!showSearch);
 
     splitterSizes = config.readEntry("EditorSplitterSizes",QList<int>());
@@ -301,17 +308,17 @@ void PlaylistSplitter::readConfig()
 
 void PlaylistSplitter::saveConfig()
 {
+    using namespace ActionCollection; // add literal
+
     KConfigGroup config(KSharedConfig::openConfig(), "Splitter");
     config.writeEntry("PlaylistSplitterSizes", sizes());
-    config.writeEntry("ShowSearch", ActionCollection::action<KToggleAction>("showSearch")->isChecked());
+    config.writeEntry("ShowSearch", "showSearch"_act->isChecked());
     config.writeEntry("EditorSplitterSizes", m_editorSplitter->sizes());
 }
 
 void PlaylistSplitter::slotShowSearchResults()
 {
-    PlaylistList playlists;
-    playlists.append(visiblePlaylist());
-    visiblePlaylist()->setSearch(m_searchWidget->search(playlists));
+    visiblePlaylist()->setSearch(m_searchWidget->search(visiblePlaylist()));
 }
 
 void PlaylistSplitter::slotPlaylistSelectionChanged()
@@ -328,7 +335,7 @@ void PlaylistSplitter::slotPlaylistChanged(int i)
 
     m_newVisible = p;
     m_searchWidget->setSearch(p->search());
-    m_newVisible = 0;
+    m_newVisible = nullptr;
 }
 
 void PlaylistSplitter::slotCurrentPlaylistChanged(QTreeWidgetItem *item)
